translate.storage

Package translate :: Package storage |
[hide private]
[frames] | no frames]

# Package storage

source code

translate.storage is part of the translate package It contains classes that represent various storage formats for localization

Submodules | [hide private]
translate.storage._factory_classes: Py2exe can't find stuff that we import dynamically, so we have this file just for the sake of the Windows installer to easily pick up all the stuff that we need and ensure they make it into the installer. translate.storage.bundleprojstore translate.storage.catkeys: Manage the Haiku catkeys translation format translate.storage.fpo: Classes for the support of Gettext .po and .pot files. translate.storage.jsonl10n: Class that manages JSON data files for translation translate.storage.mozilla_lang: A class to manage Mozilla .lang files. translate.storage.omegat: Manage the OmegaT glossary format translate.storage.project translate.storage.projstore translate.storage.trados: Manage the Trados .txt Translation Memory format translate.storage.utx: Manage the Universal Terminology eXchange (UTX) format translate.storage.workflow: A workflow is defined by a set of states that a translation unit can be in and the (allowed) transitions between these states.
Primary Localisation
translate.storage.base: Base classes for storage interfaces. translate.storage.cpo: Classes that hold units of .po files (pounit) or entire files (pofile). translate.storage.factory: factory methods to build real storage objects that conform to base.py translate.storage.po: A class loader that will load C or Python implementations of the PO class depending on the USECPO variable. translate.storage.pocommon translate.storage.poheader: class that handles all header functions for a header in a po file translate.storage.poparser translate.storage.pypo: classes that hold units of .po files (pounit) or entire files (pofile) gettext-style .po (or .pot) files are used in translations for KDE et al (see kbabel) translate.storage.xliff: Module for handling XLIFF files for translation.
Bilingual
translate.storage.lisa: Parent class for LISA standards (TMX, TBX, XLIFF) translate.storage.oo: Classes that hold units of .oo files (oounit) or entire files (oofile). translate.storage.poxliff: XLIFF classes specifically suited for handling the PO representation in XLIFF. translate.storage.qph: Module for handling Qt Linguist Phrase Book (.qph) files. translate.storage.tbx: module for handling TBX glossary files translate.storage.tmx: module for parsing TMX translation memeory files translate.storage.ts: Module for parsing Qt .ts files for translation. translate.storage.ts2: Module for handling Qt linguist (.ts) files. translate.storage.wordfast: Manage the Wordfast Translation Memory format
Monolingual
translate.storage.csvl10n: classes that hold units of comma-separated values (.csv) files (csvunit) or entire files (csvfile) for use with localisation translate.storage.dtd: classes that hold units of .dtd files (dtdunit) or entire files (dtdfile) these are specific .dtd files for localisation used by mozilla translate.storage.html: module for parsing html files for translation translate.storage.ical: Class that manages iCalender files for translation translate.storage.ini: Class that manages .ini files for translation translate.storage.php: Classes that hold units of PHP localisation files phpunit or entire files phpfile. translate.storage.properties: Classes that hold units of .properties, and similar, files that are used in translating Java, Mozilla, MacOS and other software. translate.storage.rc: Classes that hold units of .rc files (rcunit) or entire files (rcfile) used in translating Windows Resources. translate.storage.subtitles: Class that manages subtitle files for translation translate.storage.symbian translate.storage.tiki: Class that manages TikiWiki files for translation. translate.storage.txt: This class implements the functionality for handling plain text files, or similar wiki type files.
OpenDocument Format
translate.storage.odf_io translate.storage.odf_shared translate.storage.xml_extract translate.storage.xml_extract.extract translate.storage.xml_extract.generate translate.storage.xml_extract.misc translate.storage.xml_extract.unit_tree translate.storage.xml_extract.xpath_breadcrumb
Binary
translate.storage.mo: Module for parsing Gettext .mo files for translation. translate.storage.qm: Module for parsing Qt .qm files
Version Control
translate.storage.versioncontrol: This module manages interaction with version control systems. translate.storage.versioncontrol.bzr translate.storage.versioncontrol.cvs translate.storage.versioncontrol.darcs translate.storage.versioncontrol.git translate.storage.versioncontrol.hg translate.storage.versioncontrol.svn
Placeables
translate.storage.placeables: This module implements basic functionality to support placeables. translate.storage.placeables.base: Contains base placeable classes with names based on XLIFF placeables. translate.storage.placeables.general: Contains general placeable implementations. translate.storage.placeables.interfaces: This file contains abstract (semantic) interfaces for placeable implementations. translate.storage.placeables.lisa translate.storage.placeables.parse translate.storage.placeables.parse': Contains the `parse` function that parses normal strings into StringElem- based "rich" string element trees. translate.storage.placeables.strelem: Contains the base StringElem class that represents a node in a parsed rich- string tree. translate.storage.placeables.terminology: Contains the placeable that represents a terminology term. translate.storage.placeables.xliff: Contains XLIFF-specific placeables.
Other file processing
translate.storage.directory: This module provides functionality to work with directories. translate.storage.statistics: Module to provide statistics and related functionality. translate.storage.statsdb: Module to provide a cache of statistics in a database. translate.storage.xpi: module for accessing mozilla xpi packages translate.storage.zip: This module provides functionality to work with zip files.
Other
translate.storage.benchmark translate.storage.tmdb: Module to provide a translation memory database. translate.storage.xml_name

Variables | [hide private]
| __package__ = `None` hash(x)

Imports: factory, placeables, poheader